==> openGion7.0.1.4_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GE70S.sql <==
/****************************************************************************/
/* GE70 ( 取込要求ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:46                                            */
/****************************************************************************/

CREATE TABLE GE70 (
   SYSTEM_ID        VARCHAR (   10 )                    NOT NULL                                                                                                        /*   1 ｼｽﾃﾑID               */
 , RSRV_NO          INTEGER                             NOT NULL                                                                                                        /*   2 予約番号             */
 , NAME_JA          VARCHAR (  200 )                                                                                                                                    /*   3 名称                 */
 , EXECID           VARCHAR (   20 )                    NOT NULL                                                                                                        /*   4 処理ID               */
 , FGYKAN           VARCHAR (    1 )        DEFAULT '2' NOT NULL                                                                                                        /*   5 取込予約ﾌﾗｸﾞ         */
 , DIR_BASE         VARCHAR (  200 )                                                                                                                                    /*   6 取込ﾍﾞｰｽﾌｫﾙﾀﾞ        */
 , DIR_SUB          VARCHAR (  200 )                                                                                                                                    /*   7 取込ｻﾌﾞﾌｫﾙﾀﾞ         */
 , DIR_WORK         VARCHAR (  200 )                                                                                                                                    /*   8 処理ﾌｫﾙﾀﾞ(WORK)      */
 , DIR_BKUP_OK      VARCHAR (  200 )                                                                                                                                    /*   9 処理済ﾌｫﾙﾀﾞ(正常)    */
 , DIR_BKUP_NG      VARCHAR (  200 )                                                                                                                                    /*  10 処理済ﾌｫﾙﾀﾞ(異常)    */
 , FILE_FILTER      VARCHAR ( 4000 )                                                                                                                                    /*  11 検索条件             */
 , RELEASE_NOTES    VARCHAR (  120 )                                                                                                                                    /*  12 ﾘﾘｰｽﾉｰﾄ              */
 , RDC_CODE         VARCHAR (   20 )                                                                                                                                    /*  13 設変番号             */
 , UNIQ             BIGINT                              NOT NULL     generated always as identity (start with 1, increment by 1),constraint GE70 primary key(UNIQ)      /* 800 ﾕﾆｰｸｷｰ               */
 , FGJ              VARCHAR (    1 )        DEFAULT '1' NOT NULL                                                                                                        /* 810 状態ﾌﾗｸﾞ             */
 , DYSET            VARCHAR (   14 )                                                                                                                                    /* 820 登録日時             */
 , PGSET            VARCHAR (   10 )                                                                                                                                    /* 830 作成PG               */
 , PGPSET           VARCHAR (   10 )                                                                                                                                    /* 840 作成親PG             */
 , USRSET           VARCHAR (   10 )                                                                                                                                    /* 850 作成者               */
 , DYUPD            VARCHAR (   14 )                                                                                                                                    /* 860 更新日時             */
 , PGUPD            VARCHAR (   10 )                                                                                                                                    /* 870 更新PG               */
 , PGPUPD           VARCHAR (   10 )                                                                                                                                    /* 880 更新親PG             */
 , USRUPD           VARCHAR (   10 )                                                                                                                                    /* 890 更新者               */
);

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GE70S.sql <==
/****************************************************************************/
/* GE70 ( 取込要求ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:26                                            */
/****************************************************************************/

CREATE TABLE GE70 (
   SYSTEM_ID        VARCHAR (   10 )                    NOT NULL                                                                                                        /*   1 ｼｽﾃﾑID               */
 , RSRV_NO          INTEGER                             NOT NULL                                                                                                        /*   2 予約番号             */
 , NAME_JA          VARCHAR (  200 )                                                                                                                                    /*   3 名称                 */
 , EXECID           VARCHAR (   20 )                    NOT NULL                                                                                                        /*   4 処理ID               */
 , FGYKAN           VARCHAR (    1 )        DEFAULT '2' NOT NULL                                                                                                        /*   5 取込予約ﾌﾗｸﾞ         */
 , DIR_BASE         VARCHAR (  200 )                                                                                                                                    /*   6 取込ﾍﾞｰｽﾌｫﾙﾀﾞ        */
 , DIR_SUB          VARCHAR (  200 )                                                                                                                                    /*   7 取込ｻﾌﾞﾌｫﾙﾀﾞ         */
 , DIR_WORK         VARCHAR (  200 )                                                                                                                                    /*   8 処理ﾌｫﾙﾀﾞ(WORK)      */
 , DIR_BKUP_OK      VARCHAR (  200 )                                                                                                                                    /*   9 処理済ﾌｫﾙﾀﾞ(正常)    */
 , DIR_BKUP_NG      VARCHAR (  200 )                                                                                                                                    /*  10 処理済ﾌｫﾙﾀﾞ(異常)    */
 , FILE_FILTER      VARCHAR ( 4000 )                                                                                                                                    /*  11 検索条件             */
 , RELEASE_NOTES    VARCHAR (  120 )                                                                                                                                    /*  12 ﾘﾘｰｽﾉｰﾄ              */
 , RDC_CODE         VARCHAR (   20 )                                                                                                                                    /*  13 設変番号             */
 , UNIQ             BIGINT                              NOT NULL     generated always as identity (start with 1, increment by 1),constraint GE70 primary key(UNIQ)      /* 800 ﾕﾆｰｸｷｰ               */
 , FGJ              VARCHAR (    1 )        DEFAULT '1' NOT NULL                                                                                                        /* 810 状態ﾌﾗｸﾞ             */
 , DYSET            VARCHAR (   14 )                                                                                                                                    /* 820 作成日時             */
 , PGSET            VARCHAR (   10 )                                                                                                                                    /* 830 作成PG               */
 , PGPSET           VARCHAR (   10 )                                                                                                                                    /* 840 作成親PG             */
 , USRSET           VARCHAR (   10 )                                                                                                                                    /* 850 作成者               */
 , DYUPD            VARCHAR (   14 )                                                                                                                                    /* 860 更新日時             */
 , PGUPD            VARCHAR (   10 )                                                                                                                                    /* 870 更新PG               */
 , PGPUPD           VARCHAR (   10 )                                                                                                                                    /* 880 更新親PG             */
 , USRUPD           VARCHAR (   10 )                                                                                                                                    /* 890 更新者               */
);
